@@ -22,13 +22,15 @@ use function exec;
 use function extension_loaded;
 use function file_get_contents;
 use Generator;
-use function Humbug\get_contents;
+use function get_loaded_extensions;
+use function implode;
 use InvalidArgumentException;
 use function iterator_to_array;
 use function json_decode;
 use function json_encode;
 use const JSON_PRETTY_PRINT;
 use KevinGH\Box\Compactor\Php;
+use KevinGH\Box\Composer\ComposerOrchestrator;
 use KevinGH\Box\Console\DisplayNormalizer;
 use function KevinGH\Box\FileSystem\chmod;
 use function KevinGH\Box\FileSystem\dump_file;
@@ -37,12 +39,15 @@ use function KevinGH\Box\FileSystem\mirror;
 use function KevinGH\Box\FileSystem\remove;
 use function KevinGH\Box\FileSystem\rename;
 use function KevinGH\Box\FileSystem\touch;
+use function KevinGH\Box\format_size;
 use function KevinGH\Box\get_box_version;
+use function KevinGH\Box\memory_to_bytes;
 use KevinGH\Box\Test\CommandTestCase;
 use KevinGH\Box\Test\RequiresPharReadonlyOff;
 use function mt_getrandmax;
 use Phar;
 use PharFileInfo;
+use const PHP_VERSION;
 use function phpversion;
 use function preg_match;
 use function preg_quote;
@@ -56,7 +61,6 @@ use function strlen;
 use function substr;
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Output\OutputInterface;
-use Symfony\Component\Console\Tester\CommandTester;
 use Symfony\Component\Finder\Finder;
 use Symfony\Component\Process\PhpExecutableFinder;
 use Traversable;
@@ -64,6 +68,7 @@ use Traversable;
 /**
  * @covers \KevinGH\Box\Console\Command\Compile
  * @covers \KevinGH\Box\Console\MessageRenderer
+ *
  * @runTestsInSeparateProcesses This is necessary as instantiating a PHAR in memory may load/autoload some stuff which
  *                              can create undesirable side-effects.
  */
@@ -73,6 +78,16 @@ class CompileTest extends CommandTestCase
 
     private const FIXTURES_DIR = __DIR__.'/../../../fixtures/build';
 
+    private static $runComposer2 = false;
+
+    /**
+     * {@inheritdoc}
+     */
+    public static function setUpBeforeClass(): void
+    {
+        self::$runComposer2 = version_compare(ComposerOrchestrator::getVersion(), '2', '>=');
+    }
+
     /**
      * {@inheritdoc}
      */
@@ -82,19 +97,9 @@ class CompileTest extends CommandTestCase
 
         parent::setUp();
 
-        $this->commandTester = new class($this->application->get($this->getCommand()->getName())) extends CommandTester {
-            /**
-             * {@inheritdoc}
-             */
-            public function execute(array $input, array $options = [])
-            {
-                if ('compile' === $input['command']) {
-                    $input['--no-parallel'] = null;
-                }
+        $this->commandTester = new CommandTester($this->application->get($this->getCommand()->getName()));
 
-                return parent::execute($input, $options);
-            }
-        };
+        remove(self::FIXTURES_DIR.'/dir010/index.phar');
     }
 
     /**
@@ -115,6 +120,12 @@ class CompileTest extends CommandTestCase
 
         $shebang = sprintf('#!%s', (new PhpExecutableFinder())->find());
 
+        $numberOfFiles = 45;
+        if (self::$runComposer2) {
+            // From Composer 2 there are more files
+            $numberOfFiles += 2;
+        }
+
         dump_file(
             'box.json',
             json_encode(
@@ -158,7 +169,6 @@ class CompileTest extends CommandTestCase
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -188,14 +198,17 @@ Box version 3.x-dev@151e40a
 ? Removing the Composer dump artefacts
 ? No compression
 ? Signing using a private key
-Private key passphrase:
+
+ Private key passphrase:
+ >
+
 ? Setting file permissions to 0700
 * Done.
 
 No recommendation found.
 No warning found.
 
- // PHAR: 44 files (100B)
+ // PHAR: $numberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -250,8 +263,6 @@ PHP;
             '/.box/.requirements.php',
             '/.box/bin/',
             '/.box/bin/check-requirements.php',
-            '/.box/composer.json',
-            '/.box/composer.lock',
             '/.box/src/',
             '/.box/src/Checker.php',
             '/.box/src/IO.php',
@@ -266,23 +277,28 @@ PHP;
             '/.box/vendor/autoload.php',
             '/.box/vendor/composer/',
             '/.box/vendor/composer/ClassLoader.php',
+            '/.box/vendor/composer/InstalledVersions.php',
             '/.box/vendor/composer/LICENSE',
             '/.box/vendor/composer/autoload_classmap.php',
             '/.box/vendor/composer/autoload_namespaces.php',
             '/.box/vendor/composer/autoload_psr4.php',
             '/.box/vendor/composer/autoload_real.php',
             '/.box/vendor/composer/autoload_static.php',
-            '/.box/vendor/composer/installed.json',
+            '/.box/vendor/composer/platform_check.php',
             '/.box/vendor/composer/semver/',
             '/.box/vendor/composer/semver/LICENSE',
             '/.box/vendor/composer/semver/src/',
             '/.box/vendor/composer/semver/src/Comparator.php',
+            '/.box/vendor/composer/semver/src/CompilingMatcher.php',
             '/.box/vendor/composer/semver/src/Constraint/',
-            '/.box/vendor/composer/semver/src/Constraint/AbstractConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/Bound.php',
             '/.box/vendor/composer/semver/src/Constraint/Constraint.php',
             '/.box/vendor/composer/semver/src/Constraint/ConstraintInterface.php',
-            '/.box/vendor/composer/semver/src/Constraint/EmptyConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/MatchAllConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/MatchNoneConstraint.php',
             '/.box/vendor/composer/semver/src/Constraint/MultiConstraint.php',
+            '/.box/vendor/composer/semver/src/Interval.php',
+            '/.box/vendor/composer/semver/src/Intervals.php',
             '/.box/vendor/composer/semver/src/Semver.php',
             '/.box/vendor/composer/semver/src/VersionParser.php',
             '/one/',
@@ -305,6 +321,13 @@ PHP;
             '/vendor/composer/autoload_static.php',
         ];
 
+        if (!self::$runComposer2) {
+            $expectedFiles = array_values(array_filter($expectedFiles, static function ($file): bool {
+                return '/.box/vendor/composer/platform_check.php' !== $file
+                && '/.box/vendor/composer/InstalledVersions.php' !== $file;
+            }));
+        }
+
         $actualFiles = $this->retrievePharFiles($phar);
 
         $this->assertSame($expectedFiles, $actualFiles);
@@ -373,6 +396,12 @@ PHP;
 
         $version = get_box_version();
 
+        $numberOfFiles = 49;
+        if (self::$runComposer2) {
+            // From Composer 2 there are more files
+            $numberOfFiles += 2;
+        }
+
         $expected = <<<OUTPUT
 
     ____
@@ -384,7 +413,6 @@ PHP;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading without a configuration file.
 
 🔨  Building the PHAR "/path/to/tmp/index.phar"
@@ -413,7 +441,7 @@ Box version 3.x-dev@151e40a
 No recommendation found.
 No warning found.
 
- // PHAR: 48 files (100B)
+ // PHAR: $numberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -474,8 +502,6 @@ PHP;
             '/.box/.requirements.php',
             '/.box/bin/',
             '/.box/bin/check-requirements.php',
-            '/.box/composer.json',
-            '/.box/composer.lock',
             '/.box/src/',
             '/.box/src/Checker.php',
             '/.box/src/IO.php',
@@ -490,23 +516,28 @@ PHP;
             '/.box/vendor/autoload.php',
             '/.box/vendor/composer/',
             '/.box/vendor/composer/ClassLoader.php',
+            '/.box/vendor/composer/InstalledVersions.php',
             '/.box/vendor/composer/LICENSE',
             '/.box/vendor/composer/autoload_classmap.php',
             '/.box/vendor/composer/autoload_namespaces.php',
             '/.box/vendor/composer/autoload_psr4.php',
             '/.box/vendor/composer/autoload_real.php',
             '/.box/vendor/composer/autoload_static.php',
-            '/.box/vendor/composer/installed.json',
+            '/.box/vendor/composer/platform_check.php',
             '/.box/vendor/composer/semver/',
             '/.box/vendor/composer/semver/LICENSE',
             '/.box/vendor/composer/semver/src/',
             '/.box/vendor/composer/semver/src/Comparator.php',
+            '/.box/vendor/composer/semver/src/CompilingMatcher.php',
             '/.box/vendor/composer/semver/src/Constraint/',
-            '/.box/vendor/composer/semver/src/Constraint/AbstractConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/Bound.php',
             '/.box/vendor/composer/semver/src/Constraint/Constraint.php',
             '/.box/vendor/composer/semver/src/Constraint/ConstraintInterface.php',
-            '/.box/vendor/composer/semver/src/Constraint/EmptyConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/MatchAllConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/MatchNoneConstraint.php',
             '/.box/vendor/composer/semver/src/Constraint/MultiConstraint.php',
+            '/.box/vendor/composer/semver/src/Interval.php',
+            '/.box/vendor/composer/semver/src/Intervals.php',
             '/.box/vendor/composer/semver/src/Semver.php',
             '/.box/vendor/composer/semver/src/VersionParser.php',
             '/binary',
@@ -532,6 +563,13 @@ PHP;
             '/vendor/composer/autoload_static.php',
         ];
 
+        if (!self::$runComposer2) {
+            $expectedFiles = array_values(array_filter($expectedFiles, static function ($file): bool {
+                return '/.box/vendor/composer/platform_check.php' !== $file
+                && '/.box/vendor/composer/InstalledVersions.php' !== $file;
+            }));
+        }
+
         $actualFiles = $this->retrievePharFiles($phar);
 
         $this->assertSame($expectedFiles, $actualFiles);
@@ -596,7 +634,6 @@ PHP;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -793,6 +830,14 @@ PHP;
 
         $shebang = sprintf('#!%s', (new PhpExecutableFinder())->find());
 
+        $numberOfClasses = 0;
+        $numberOfFiles = 45;
+        if (self::$runComposer2) {
+            // From Composer 2 there are more files
+            ++$numberOfClasses;
+            $numberOfFiles += 2;
+        }
+
         dump_file(
             'box.json',
             json_encode(
@@ -839,7 +884,6 @@ PHP;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -866,17 +910,24 @@ Box version 3.x-dev@151e40a
   'rand' => $rand,
 )
 ? Dumping the Composer autoloader
+    > '/usr/local/bin/composer' 'dump-autoload' '--classmap-authoritative' '--no-dev'
+Generating optimized autoload files (authoritative)
+Generated optimized autoload files (authoritative) containing $numberOfClasses classes
+
 ? Removing the Composer dump artefacts
 ? No compression
 ? Signing using a private key
-Private key passphrase:
+
+ Private key passphrase:
+ >
+
 ? Setting file permissions to 0754
 * Done.
 
 No recommendation found.
 No warning found.
 
- // PHAR: 44 files (100B)
+ // PHAR: $numberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -886,6 +937,12 @@ OUTPUT;
 
         $actual = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
+        $actual = preg_replace(
+            '/(\/.*?composer)/',
+            '/usr/local/bin/composer',
+            $actual
+        );
+
         $this->assertSame($expected, $actual);
     }
 
@@ -895,6 +952,14 @@ OUTPUT;
 
         $shebang = sprintf('#!%s', (new PhpExecutableFinder())->find());
 
+        $numberOfClasses = 0;
+        $numberOfFiles = 45;
+        if (self::$runComposer2) {
+            // From Composer 2 there are more files
+            ++$numberOfClasses;
+            $numberOfFiles += 2;
+        }
+
         dump_file(
             'box.json',
             json_encode(
@@ -944,7 +1009,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -972,17 +1036,24 @@ Box version 3.x-dev@151e40a
   'rand' => $rand,
 )
 ? Dumping the Composer autoloader
+    > '/usr/local/bin/composer' 'dump-autoload' '--classmap-authoritative' '--no-dev' '-v'
+Generating optimized autoload files (authoritative)
+Generated optimized autoload files (authoritative) containing $numberOfClasses classes
+
 ? Removing the Composer dump artefacts
 ? No compression
 ? Signing using a private key
-Private key passphrase:
+
+ Private key passphrase:
+ >
+
 ? Setting file permissions to 0754
 * Done.
 
 No recommendation found.
 No warning found.
 
- // PHAR: 44 files (100B)
+ // PHAR: $numberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -995,8 +1066,15 @@ OUTPUT;
             (new PhpExecutableFinder())->find(),
             $expected
         );
+
         $actual = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
+        $actual = preg_replace(
+            '/(\/.*?composer)/',
+            '/usr/local/bin/composer',
+            $actual
+        );
+
         $this->assertSame($expected, $actual);
     }
 
@@ -1023,7 +1101,7 @@ PHP
 JSON
         );
 
-        $this->assertDirectoryNotExists('.box_dump');
+        $this->assertDirectoryDoesNotExist('.box_dump');
 
         $this->commandTester->execute(
             [
@@ -1048,7 +1126,13 @@ JSON
             $xdebugLog = '[debug] The xdebug extension is not loaded';
         }
 
+        $memoryLog = sprintf(
+            '[debug] Current memory limit: "%s"',
+            format_size(memory_to_bytes(trim(ini_get('memory_limit'))), 0)
+        );
+
         $expected = <<<OUTPUT
+$memoryLog
 [debug] Checking BOX_ALLOW_XDEBUG
 $xdebugLog
 [debug] Disabled parallel processing
@@ -1062,7 +1146,6 @@ $xdebugLog
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/index.phar"
@@ -1120,10 +1203,16 @@ OUTPUT;
         $expectedDumpedConfig = <<<'EOF'
 //
 // Processed content of the configuration file "/path/to/box.json" dumped for debugging purposes
+//
+// PHP Version: 10.0.0
+// PHP extensions: Core,date
+// OS: Darwin / 17.7.0
+// Command: bin/phpunit
+// Box: 3.x-dev@27df576
 // Time: 2018-05-24T20:59:15+00:00
 //
 
-KevinGH\Box\Configuration {#140
+KevinGH\Box\Configuration\Configuration {#140
   -file: "box.json"
   -fileMode: "0755"
   -alias: "index.phar"
@@ -1183,12 +1272,65 @@ EOF;
             file_contents('.box_dump/.box_configuration')
         );
 
+        // Replace objects IDs
         $actualDumpedConfig = preg_replace(
             '/ \{#\d{3,}/',
             ' {#140',
             $actualDumpedConfig
         );
 
+        // Replace the expected PHP version
+        $actualDumpedConfig = str_replace(
+            sprintf(
+                'PHP Version: %s',
+                PHP_VERSION
+            ),
+            'PHP Version: 10.0.0',
+            $actualDumpedConfig
+        );
+
+        // Replace the expected PHP extensions
+        $actualDumpedConfig = str_replace(
+            sprintf(
+                'PHP extensions: %s',
+                implode(',', get_loaded_extensions())
+            ),
+            'PHP extensions: Core,date',
+            $actualDumpedConfig
+        );
+
+        // Replace the expected OS version
+        $actualDumpedConfig = str_replace(
+            sprintf(
+                'OS: %s / %s',
+                PHP_OS,
+                php_uname('r')
+            ),
+            'OS: Darwin / 17.7.0',
+            $actualDumpedConfig
+        );
+
+        // Replace the expected command
+        $actualDumpedConfig = str_replace(
+            sprintf(
+                'Command: %s',
+                implode(' ', $GLOBALS['argv'])
+            ),
+            'Command: bin/phpunit',
+            $actualDumpedConfig
+        );
+
+        // Replace the expected Box version
+        $actualDumpedConfig = str_replace(
+            sprintf(
+                'Box: %s',
+                get_box_version()
+            ),
+            'Box: 3.x-dev@27df576',
+            $actualDumpedConfig
+        );
+
+        // Replace the expected time
         $actualDumpedConfig = preg_replace(
             '/Time: \d{4,}-\d{2,}-\d{2,}T\d{2,}:\d{2,}:\d{2,}\+\d{2,}:\d{2,}/',
             'Time: 2018-05-24T20:59:15+00:00',
@@ -1199,7 +1341,7 @@ EOF;
 
         // Checks one of the dumped file from the PHAR to ensure the encoding of the extracted file is correct
         $this->assertSame(
-            get_contents('.box_dump/index.php'),
+            file_get_contents('.box_dump/index.php'),
             $indexContents
         );
     }
@@ -1261,8 +1403,8 @@ EOF;
         $pharContents = file_get_contents('test.phar');
         $shebang = preg_quote($shebang, '/');
 
-        $this->assertRegExp("/$shebang/", $pharContents);
-        $this->assertRegExp('/custom banner/', $pharContents);
+        $this->assertMatchesRegularExpression("/$shebang/", $pharContents);
+        $this->assertMatchesRegularExpression('/custom banner/', $pharContents);
 
         $phar = new Phar('test.phar');
 
@@ -1445,7 +1587,7 @@ PHP
 
             $this->fail('Expected exception to be thrown.');
         } catch (InvalidArgumentException $exception) {
-            $this->assertRegExp(
+            $this->assertMatchesRegularExpression(
                 '/^Path ".+?" was expected to be readable\.$/',
                 $exception->getMessage()
             );
@@ -1477,7 +1619,6 @@ PHP
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -1534,7 +1675,7 @@ OUTPUT;
 
         rename('run.php', 'index.php');
 
-        $this->assertFileNotExists($this->tmp.'/vendor/autoload.php');
+        $this->assertFileDoesNotExist($this->tmp.'/vendor/autoload.php');
 
         $this->commandTester->execute(
             ['command' => 'compile'],
@@ -1543,7 +1684,7 @@ OUTPUT;
 
         $output = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
-        $this->assertRegExp(
+        $this->assertMatchesRegularExpression(
             '/\? Dumping the Composer autoloader/',
             $output,
             'Expected the autoloader to be dumped'
@@ -1572,7 +1713,7 @@ OUTPUT;
 
         rename('run.php', 'index.php');
 
-        $this->assertFileNotExists($this->tmp.'/vendor/autoload.php');
+        $this->assertFileDoesNotExist($this->tmp.'/vendor/autoload.php');
 
         dump_file(
             'box.json',
@@ -1590,7 +1731,7 @@ OUTPUT;
 
         $output = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
-        $this->assertRegExp(
+        $this->assertMatchesRegularExpression(
             '/\? Skipping dumping the Composer autoloader/',
             $output,
             'Did not expect the autoloader to be dumped'
@@ -1609,7 +1750,7 @@ OUTPUT;
         ];
 
         foreach ($composerFiles as $composerFile) {
-            $this->assertFileNotExists('phar://index.phar/'.$composerFile);
+            $this->assertFileDoesNotExist('phar://index.phar/'.$composerFile);
         }
     }
 
@@ -1619,7 +1760,7 @@ OUTPUT;
 
         rename('run.php', 'index.php');
 
-        $this->assertFileNotExists($this->tmp.'/vendor/autoload.php');
+        $this->assertFileDoesNotExist($this->tmp.'/vendor/autoload.php');
 
         $this->commandTester->execute(
             ['command' => 'compile'],
@@ -1628,7 +1769,7 @@ OUTPUT;
 
         $output = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
-        $this->assertRegExp(
+        $this->assertMatchesRegularExpression(
             '/\? Removing the Composer dump artefacts/',
             $output,
             'Expected the composer files to be removed'
@@ -1657,7 +1798,7 @@ OUTPUT;
         ];
 
         foreach ($removedComposerFiles as $composerFile) {
-            $this->assertFileNotExists('phar://index.phar/'.$composerFile);
+            $this->assertFileDoesNotExist('phar://index.phar/'.$composerFile);
         }
     }
 
@@ -1672,7 +1813,7 @@ OUTPUT;
             json_encode(['exclude-composer-files' => false])
         );
 
-        $this->assertFileNotExists($this->tmp.'/vendor/autoload.php');
+        $this->assertFileDoesNotExist($this->tmp.'/vendor/autoload.php');
 
         $this->commandTester->execute(
             ['command' => 'compile'],
@@ -1681,7 +1822,7 @@ OUTPUT;
 
         $output = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
-        $this->assertRegExp(
+        $this->assertMatchesRegularExpression(
             '/\? Keep the Composer dump artefacts/',
             $output,
             'Expected the composer files to be kept'
@@ -1741,7 +1882,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -1809,7 +1949,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -1877,7 +2016,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -1953,7 +2091,6 @@ JSON
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -2029,7 +2166,6 @@ JSON
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -2105,7 +2241,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -2184,7 +2319,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/foo/bar/test.phar"
@@ -2280,11 +2414,11 @@ OUTPUT;
         if ($stub) {
             $this->assertSame($phar->getPath(), $phar->getAlias());
 
-            $this->assertNotRegExp(
+            $this->assertDoesNotMatchRegularExpression(
                 '/Phar::webPhar\(.*\);/',
                 $actualStub
             );
-            $this->assertRegExp(
+            $this->assertMatchesRegularExpression(
                 '/Phar::mapPhar\(\'alias-test\.phar\'\);/',
                 $actualStub
             );
@@ -2295,7 +2429,7 @@ OUTPUT;
 
             // No alias is found: I find it weird but well, that's the default stub so there is not much that can
             // be done here. Maybe there is a valid reason I'm not aware of.
-            $this->assertNotRegExp(
+            $this->assertDoesNotMatchRegularExpression(
                 '/alias-test\.phar/',
                 $actualStub
             );
@@ -2316,7 +2450,7 @@ OUTPUT;
 
         $boxRawConfig = json_decode(file_get_contents('box.json'), true, 512, JSON_PRETTY_PRINT);
         $boxRawConfig['shebang'] = false;
-        dump_file('box.json', json_encode($boxRawConfig), JSON_PRETTY_PRINT);
+        dump_file('box.json', json_encode($boxRawConfig, JSON_PRETTY_PRINT));
 
         $this->commandTester->execute(
             ['command' => 'compile'],
@@ -2339,7 +2473,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test.phar"
@@ -2429,7 +2562,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/test"
@@ -2642,7 +2774,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/index.phar"
@@ -2720,7 +2851,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/index.phar"
@@ -2783,6 +2913,12 @@ OUTPUT;
 
         $version = get_box_version();
 
+        $numberOfFiles = 41;
+        if (self::$runComposer2) {
+            // From Composer 2 there are more files
+            $numberOfFiles += 2;
+        }
+
         $expected = <<<OUTPUT
 
     ____
@@ -2794,7 +2930,6 @@ OUTPUT;
 
 Box version 3.x-dev@151e40a
 
-
  // Loading the configuration file "/path/to/box.json.dist".
 
 🔨  Building the PHAR "/path/to/tmp/index.phar"
@@ -2823,7 +2958,7 @@ Box version 3.x-dev@151e40a
 No recommendation found.
 No warning found.
 
- // PHAR: 40 files (100B)
+ // PHAR: $numberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -2875,7 +3010,7 @@ OUTPUT;
         );
 
         $display = preg_replace(
-            '/\/\/ Memory usage: \d+\.\d{2}MB \(peak: \d+\.\d{2}MB\), time: \d+\.\d{2}s/',
+            '/\/\/ Memory usage: \d+\.\d{2}MB \(peak: \d+\.\d{2}MB\), time: .*?sec/',
             '// Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s',
             $display
         );
@@ -2886,6 +3021,32 @@ OUTPUT;
             $display
         );
 
+        $display = str_replace(
+            'Xdebug',
+            'xdebug',
+            $display
+        );
+
+        $display = preg_replace(
+            '/\[debug\] Increased the maximum number of open file descriptors from \([^\)]+\) to \([^\)]+\)'.PHP_EOL.'/',
+            '',
+            $display
+        );
+
+        $display = str_replace(
+            '[debug] Restored the maximum number of open file descriptors'.PHP_EOL,
+            '',
+            $display
+        );
+
+        if (extension_loaded('xdebug')) {
+            $display = preg_replace(
+                '/'.PHP_EOL.'You are running composer with xdebug enabled. This has a major impact on runtime performance. See https:\/[^\s]+'.PHP_EOL.'/',
+                '',
+                $display
+            );
+        }
+
         return DisplayNormalizer::removeTrailingSpaces($display);
     }
 
